use v6.c;

use lib 't/spec/packages';

use B::Grammar;

class B { 
    method foo { 'method foo' }
}

